@@ -28,13 +28,15 @@ $title = $custom_title ?: get_the_title();
 
                 <?= $content; ?>
             </div>
-
-            <div class="s-introContent__imageWrap">
-                <?= Blue2\Scruffy\Utils::acf_img($image, [
-                    'class'     => 's-introContent__img',
-                    'loading'   => 'eager'
-                ]); ?>
-            </div>
+            <?php if($image){ ?>
+                <div class="s-introContent__imageWrap">
+                    <?= Blue2\Scruffy\Utils::acf_img($image, [
+                        'class'     => 's-introContent__img',
+                        'loading'   => 'eager',
+                        'size'      => '16by9'
+                    ]); ?>
+                </div>
+            <?php } ?>
         </div>
     </div>
 </section>
